==> haskell-ghc-tcplugins-extra-0.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-Ebvoj9UwWkK1Ku3MQihAC5
key: ghc-tcplugins-extra-0.3-Ebvoj9UwWkK1Ku3MQihAC5
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: b7fbb05956265567856453c3e7b8ed18
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-Ebvoj9UwWkK1Ku3MQihAC5
depends:
    base-4.12.0.0 ghc-8.6.4
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
key: ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 107a90dcdfb94a217d63d763def5bb05
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
depends:
    base-4.12.0.0 ghc-8.6.5
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
